r"""
Sage variable definitions for Debian
"""
SAGE_DOC                      = '/usr/share/doc/sagemath'

CONWAY_POLYNOMIALS_DATA_DIR   = '/usr/share/sagemath/conway_polynomials'
GRAPHS_DATA_DIR               = '/usr/share/sagemath/graphs'
ELLCURVE_DATA_DIR             = '/usr/share/sagemath/ellcurves'
POLYTOPE_DATA_DIR             = '/usr/share/sagemath/reflexive_polytopes'
GAP_ROOT_DIR                  = '/usr/share/gap'
THEBE_DIR                     = '/usr/share/thebe'
COMBINATORIAL_DESIGN_DATA_DIR = '/usr/share/sagemath/combinatorial_designs'
CREMONA_MINI_DATA_DIR         = '/usr/share/sagemath/cremona'

JMOL_DIR                      = '/usr/share/jmol'
MATHJAX_DIR                   = '/usr/share/javascript/mathjax'
THREEJS_DIR                   = '/usr/share/javascript/three'

PPLPY_DOCS                    = '/usr/share/doc/python3-ppl/html'
MAXIMA                        = 'maxima-sage'
MAXIMA_FAS                    = '/usr/lib/ecl/maxima.fas'
SAGE_NAUTY_BINS_PREFIX        = 'nauty-'
ARB_LIBRARY                   = 'flint-arb'
LIBSINGULAR_PATH              = 'libsingular-Singular.so'



#!/usr/bin/python3

import debian.deb822
import re
import subprocess

pkgdeps = []
for paragraph in debian.deb822.Deb822.iter_paragraphs(open('debian/control')):
    for item in paragraph.items():
        if item[0] == 'Build-Depends':
            pkgdeps = pkgdeps + [x.strip() for x in item[1].split(',')]
        if item[0] == 'Depends':
            pkgdeps = pkgdeps + [x.strip() for x in item[1].split(',')]
pkgdeps = [x for x in pkgdeps if not (re.match(r'\$.*', x) or x == '')]
pkgdeps = sorted(set([re.sub(r' .*', r'', x) for x in pkgdeps]))

sagedeps = subprocess.run([
    '/bin/sh', '-c',
    'for dt in sage/build/pkgs/*/distros/debian.txt; do cat $dt; done'
],stdout=subprocess.PIPE).stdout.decode().split('\n')
sagedeps = sorted(set(' '.join([re.sub(r'#.*', r'', x) for x in sagedeps]).split()))

onlypkg = [x for x in pkgdeps if not x in sagedeps]
onlysage = [x for x in sagedeps if not x in pkgdeps]

print("Package dependencies that do not appear in debian.txt files:")
print(' '.join(onlypkg))

print("Entries in debian.txt files that do not appear in package dependencies:")
print(' '.join(onlysage))
